clc, close all, clear all

%% Notes
% This is an example script showing how to use the waterfall plunge pool
% sediment transport capacity script ('Qsc_pool_public.m')

% This script shows how waterfall plunge-pool sediment-transport capacity
% varies as a function of water discharge, grain size, waterfall drop
% height, and flow depth using base values from  Lower Switzer Falls,
% Arroyo Seco, San Gabrial Mountains (LSF, Table S1)
% You'll notice kinks in the plots made in this script,
% most of these have to do with switching between the ZOFE and ZOEF.

% I also provide an example of applying the sediment-transport capacity
% theory in inverse to predict steady-state alluvial-pool depth

% Code written by J. Scheingross
% Last modified 19 October 2015
% Please report errors in the code to jscheingross .a.t. gmail dot com.

%% Input values from Lower Switzer Falls (LSF, Table S1)
Cf_river = 0.01; %River friction factor estimation
w_upstream = 5; %Upstream width (m)
D50 = 0.1; % grain size (m)
r_pool = 4.375; % pool radius (m)
h_pool = 2; % pool depth (m)
H_drop = 5; % waterfall drop height (m)
S_upstream = 0.035; % upstream slope
Q2yr = 4.81; % 2yr recurrance interval flood discharge (m3/s)

[Qsc_LSF] = Qsc_pool_public(r_pool, Q2yr, h_pool, H_drop, w_upstream, ...
        D50, S_upstream, Cf_river) % The base case of plunge-pool sediment-transport capacity for Lower Switzer Falls

%% Predict steady-state alluvial depth via iterating with Qsc_pool theory

% Step 1: Set the sedimenet supply and water discharge you want to
% predict steady-state depth for
Q_use = Q2yr; %water discharge
Qs_supply = 1.5e-4; %sediment supply (m3/s)

% Step 2: set up a vector of possible steady-state depths to iterate over
depth_range = linspace(0.01, 5, 100);

% Step 3: calcualte Qsc_pool for each depth
for i = 1:length(depth_range)
    [Qsc_pool_vector(i)] = Qsc_pool_public(r_pool, Q2yr, depth_range(i), H_drop, w_upstream, ...
        D50, S_upstream, Cf_river);
end

% Step 4: keep only the unique values from the vector
[junk, i1] = unique(Qsc_pool_vector);
unique_Qsc_vector = Qsc_pool_vector(i1);
unique_depth_range = depth_range(i1);

% Step 5: interpolate to find the steady-state depth
steady_state_depth = interp1(unique_Qsc_vector,unique_depth_range,Qs_supply); 

%% Calculate plunge pool sediment transport capacity varying one parameter 
% while holding everything else constant

% Vary water discharge
Qrange = logspace(-1,4,10000);
for i = 1:length(Qrange)
    [Qsc_pool_vary_Q(i)] = Qsc_pool_public(r_pool, Qrange(i), h_pool, H_drop, w_upstream, ...
        D50, S_upstream, Cf_river);
end

% Vary grain diameter
D_range = logspace(-3,1,10000);
for i = 1:length(D_range)
    [Qsc_pool_vary_D(i)] = Qsc_pool_public(r_pool, Q2yr, h_pool, H_drop, w_upstream, ...
        D_range(i), S_upstream, Cf_river);
end

% Vary waterfall drop height
Hrange = logspace(0,3,10000);
for i = 1:length(Hrange)
    [Qsc_pool_vary_H(i)] = Qsc_pool_public(r_pool, Q2yr, h_pool, Hrange(i), w_upstream, ...
        D50, S_upstream, Cf_river);
end

% Vary pool depth
h_pool_range = logspace(-2,2, 10000);
for i = 1:length(h_pool_range)
    [Qsc_pool_vary_hpool(i)] = Qsc_pool_public(r_pool, Q2yr, h_pool_range(i), H_drop, w_upstream, ...
        D50, S_upstream, Cf_river);
end

%% Plot up the theory predictions
figure
subplot(2,2,1)
loglog(Qrange, Qsc_pool_vary_Q, 'k-', 'linewidth', 1)
hold on
loglog(Q2yr, Qsc_LSF, 'ks', 'markerfacecolor', [0.5 0.5 0.5])
xlabel('Water discharge (m3/s)')
ylabel('Plunge-pool sediment-transport capacity (m3/s)')

subplot(2,2,2)
loglog(D_range, Qsc_pool_vary_D, 'k-', 'linewidth', 1)
hold on
loglog(D50, Qsc_LSF, 'ks', 'markerfacecolor', [0.5 0.5 0.5])
xlabel('Grain size (m)')
ylabel('Plunge-pool sediment-transport capacity (m3/s)')

subplot(2,2,3)
loglog(Hrange, Qsc_pool_vary_H, 'k-', 'linewidth', 1)
hold on
loglog(H_drop, Qsc_LSF, 'ks', 'markerfacecolor', [0.5 0.5 0.5])
xlabel('Waterfall drop height (m)')
ylabel('Plunge-pool sediment-transport capacity (m3/s)')

subplot(2,2,4)
loglog(h_pool_range, Qsc_pool_vary_hpool, 'k-', 'linewidth', 1)
hold on
loglog(h_pool, Qsc_LSF, 'ks', 'markerfacecolor', [0.5 0.5 0.5])
legend('Theory prediction', 'Lower Switzer Falls (LSF, Table S1)')
xlabel('Pool Depth (m)')
ylabel('Plunge-pool sediment-transport capacity (m3/s)')
